==> foundry_platform_sdk-0.19.0.tar.gz: foundry_platform_sdk-0.19.0/foundry/v1/ontologies/models/_ontology_object.py <==
#  Copyright 2024 Palantir Technologies, Inc.
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.


from __future__ import annotations

from typing import Dict
from typing import Optional
from typing import cast

from pydantic import BaseModel

from foundry.v1.ontologies.models._object_rid import ObjectRid
from foundry.v1.ontologies.models._ontology_object_dict import OntologyObjectDict
from foundry.v1.ontologies.models._property_api_name import PropertyApiName
from foundry.v1.ontologies.models._property_value import PropertyValue


class OntologyObject(BaseModel):
    """Represents an object in the Ontology."""

    properties: Dict[PropertyApiName, Optional[PropertyValue]]
    """A map of the property values of the object."""

    rid: ObjectRid

    model_config = {"extra": "allow"}

    def to_dict(self) -> OntologyObjectDict:
        """Return the dictionary representation of the model using the field aliases."""
        return cast(OntologyObjectDict, self.model_dump(by_alias=True, exclude_unset=True))

==> foundry_platform_sdk-0.43.0.tar.gz: foundry_platform_sdk-0.43.0/foundry/v1/ontologies/models/_ontology_object.py <==
#  Copyright 2024 Palantir Technologies, Inc.
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.


from __future__ import annotations

from typing import Dict
from typing import Optional
from typing import cast

import pydantic

from foundry.v1.ontologies.models._object_rid import ObjectRid
from foundry.v1.ontologies.models._ontology_object_dict import OntologyObjectDict
from foundry.v1.ontologies.models._property_api_name import PropertyApiName
from foundry.v1.ontologies.models._property_value import PropertyValue


class OntologyObject(pydantic.BaseModel):
    """Represents an object in the Ontology."""

    properties: Dict[PropertyApiName, Optional[PropertyValue]]
    """A map of the property values of the object."""

    rid: ObjectRid

    model_config = {"extra": "allow"}

    def to_dict(self) -> OntologyObjectDict:
        """Return the dictionary representation of the model using the field aliases."""
        return cast(OntologyObjectDict, self.model_dump(by_alias=True, exclude_unset=True))
